require File.expand_path("../message/version", __FILE__)
require 'protocol_buffers'
require 'stringio'

module Evrone
  module CI
    module Message

      module Serializable
        def to_serialized_string
          StringIO.open do |io|
            serialize(io)
            io.rewind
            io.read
          end
        end
      end

      class PerformBuild < ProtocolBuffers::Message

        include Serializable

        required :uint64,  :id,              1
        required :string,  :name,            2
        required :string,  :src,             3
        required :string,  :sha,             4
        optional :uint64,  :pull_request_id, 5
        optional :string,  :deploy_key,      6

      end

      class PerformJob < ProtocolBuffers::Message

        include Serializable

        required :uint64,  :id,              1
        required :string,  :name,            2
        required :string,  :src,             3
        required :string,  :sha,             4
        optional :uint64,  :pull_request_id, 5
        optional :string,  :deploy_key,      6

        required :uint64,  :job_id,          7

        required :string,  :before_script,   8
        required :string,  :script,          9

        repeated :string,  :matrix_keys,     10
      end

      class BuildLog < ProtocolBuffers::Message

        include Serializable

        required :uint64,  :build_id,        1
        required :string,  :log,             2
        required :uint64,  :tm,              3
        required :uint32,  :tm_usec,         4

      end

      class JobLog < ProtocolBuffers::Message

        include Serializable

        required :uint64,  :build_id,        1
        required :string,  :log,             2
        required :uint64,  :tm,              3
        required :uint32,  :tm_usec,         4
        required :uint64,  :job_id,          5

      end

      module Status

        include ProtocolBuffers::Enum

        Pending  = 0
        Prepared = 1
        Started  = 2
        Finished = 3
        Broken   = 4
        Failed   = 5

      end

      class BuildStatus < ProtocolBuffers::Message

        include Serializable

        required :uint64,  :build_id,        1
        required Status,   :status,          2
        required :uint64,  :tm,              3
        required :uint32,  :tm_usec,         4

        required :uint32,  :jobs_count,      5
        repeated :string,  :matrix,          6

        optional :string,  :commit_author,   7
        optional :string,  :commit_author_email,   8
        optional :string,  :commit_sha,      9
        optional :string,  :commit_message,  10

      end

      class JobStatus < BuildStatus

        include Serializable

        required :uint64,  :build_id,        1
        required :uint64,  :job_id,          2
        required Status,   :status,          3
        required :uint64,  :tm,              4
        required :uint32,  :tm_usec,         5

        repeated :string,  :matrix,          6

      end

    end
  end
end
